@@ -21,30 +21,32 @@
  */
 
 #include <config.h>
-#include "ev-application.h"
-#include "ev-utils.h"
-#include "ev-file-helpers.h"
-#include "ev-document-factory.h"
-#include "totem-scrsaver.h"
+
+#include <string.h>
 
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <glib-object.h>
-#include <gtk/gtkfilechooserdialog.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkmain.h>
+#include <gtk/gtk.h>
 
 #if WITH_GNOME
 #include <libgnomeui/gnome-client.h>
 #endif
 
-#ifdef ENABLE_DBUS
-#include "ev-application-service.h"
-#include <dbus/dbus-glib-bindings.h>
-#endif
+#include "totem-scrsaver.h"
 
-#include <string.h>
+#include "ev-application.h"
+#include "ev-document-factory.h"
+#include "ev-file-helpers.h"
+#include "ev-utils.h"
+
+#ifdef ENABLE_DBUS
+#include "ev-media-player-keys.h"
+#endif /* ENABLE_DBUS */
+
+#ifdef ENABLE_DBUS
+#include <dbus/dbus-glib-bindings.h>
+#include "ev-application-service.h"
+#endif
 
 static void ev_application_add_icon_path_for_screen (GdkScreen *screen);
 
@@ -59,6 +61,10 @@ struct _EvApplication {
 
 	gchar *last_chooser_uri;
 
+#ifdef ENABLE_DBUS
+	EvMediaPlayerKeys *keys;
+#endif /* ENABLE_DBUS */
+
 	GtkPrintSettings *print_settings;
 #if GTK_CHECK_VERSION (2, 11, 0)
 	gchar            *print_settings_file;
@@ -715,6 +721,10 @@ ev_application_init (EvApplication *ev_application)
 
 	egg_toolbars_model_set_flags (ev_application->toolbars_model, 0,
 				      EGG_TB_MODEL_NOT_REMOVABLE);
+
+#ifdef ENABLE_DBUS
+	ev_application->keys = ev_media_player_keys_new ();
+#endif /* ENABLE_DBUS */
 }
 
 /**
@@ -744,6 +754,26 @@ ev_application_get_windows (EvApplication *application)
 	return windows;
 }
 
+/**
+ * ev_application_get_media_keys:
+ * @application: The instance of the application.
+ *
+ * It gives you access to the media player keys handler object.
+ *
+ * Returns: A #EvMediaPlayerKeys.
+ */
+GObject
+*ev_application_get_media_keys (EvApplication *application)
+{
+#ifdef ENABLE_DBUS
+	if (!application->keys)
+		return NULL;
+	return g_object_ref (G_OBJECT (application->keys));
+#else
+	return NULL;
+#endif /* ENABLE_DBUS */
+}
+
 EggToolbarsModel *
 ev_application_get_toolbars_model (EvApplication *application)
 {
