@@ -27,14 +27,13 @@
 #include "config.h"
 #endif
 
-#include <glib/gerror.h>
-#include <glib-object.h>
-#include <gtk/gtkprintsettings.h>
-
-#include "ev-window.h"
+#include <glib.h>
+#include <gtk/gtk.h>
 
 #include "egg-toolbars-model.h"
 
+#include "ev-window.h"
+
 G_BEGIN_DECLS
 
 typedef struct _EvApplication EvApplication;
@@ -78,6 +77,7 @@ void	          ev_application_open_uri_list       (EvApplication   *application,
 						      GdkScreen       *screen,
     						      guint32          timestamp);
 GList		 *ev_application_get_windows	     (EvApplication   *application);
+GObject		 *ev_application_get_media_keys	     (EvApplication   *application);
 
 EggToolbarsModel *ev_application_get_toolbars_model  (EvApplication   *application);
 void              ev_application_save_toolbars_model (EvApplication   *application);
