@@ -27,16 +27,17 @@
 #endif
 
 #include <string.h>
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
 
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+
+#include "ev-document-misc.h"
+#include "ev-document-thumbnails.h"
+#include "ev-job-scheduler.h"
 #include "ev-sidebar-page.h"
 #include "ev-sidebar-thumbnails.h"
-#include "ev-document-thumbnails.h"
-#include "ev-document-misc.h"
-#include "ev-job-queue.h"
-#include "ev-window.h"
 #include "ev-utils.h"
+#include "ev-window.h"
 
 #define THUMBNAIL_WIDTH 100
 
@@ -207,7 +208,7 @@ clear_range (EvSidebarThumbnails *sidebar_thumbnails,
 
 		if (job) {
 			g_signal_handlers_disconnect_by_func (job, thumbnail_job_completed_callback, sidebar_thumbnails);
-			ev_job_queue_remove_job (EV_JOB (job));
+			ev_job_cancel (EV_JOB (job));
 			g_object_unref (job);
 		}
 
@@ -228,7 +229,7 @@ get_scale_for_page (EvSidebarThumbnails *sidebar_thumbnails,
 	gint width, height;
 
 	ev_page_cache_get_size (priv->page_cache,
-				page, priv->rotation,
+				page, 0,
 				1.0, &width, &height);
 	
 	return (gdouble)THUMBNAIL_WIDTH / (gdouble)width;
@@ -260,13 +261,10 @@ add_range (EvSidebarThumbnails *sidebar_thumbnails,
 				    -1);
 
 		if (job == NULL && !thumbnail_set) {
-			EvRenderContext *rc;
-
-			rc = ev_render_context_new (priv->rotation, page,
+			job = ev_job_thumbnail_new (priv->document,
+						    page, priv->rotation,
 						    get_scale_for_page (sidebar_thumbnails, page));
-			job = ev_job_thumbnail_new (priv->document, rc);
-			ev_job_queue_add_job (EV_JOB (job), EV_JOB_PRIORITY_HIGH);
-			g_object_unref (rc);
+			ev_job_scheduler_push_job (EV_JOB (job), EV_JOB_PRIORITY_HIGH);
 			
 			g_object_set_data_full (G_OBJECT (job), "tree_iter",
 						gtk_tree_iter_copy (&iter),
@@ -304,10 +302,10 @@ update_visible_range (EvSidebarThumbnails *sidebar_thumbnails,
 		return;
 
 	/* Clear the areas we no longer display */
-	if (old_start_page < start_page)
+	if (old_start_page >= 0 && old_start_page < start_page)
 		clear_range (sidebar_thumbnails, old_start_page, MIN (start_page - 1, old_end_page));
-
-	if (old_end_page > end_page)
+	
+	if (old_end_page > 0 && old_end_page > end_page)
 		clear_range (sidebar_thumbnails, MAX (end_page + 1, old_start_page), old_end_page);
 
 	add_range (sidebar_thumbnails, start_page, end_page);
@@ -333,12 +331,22 @@ adjustment_changed_cb (EvSidebarThumbnails *sidebar_thumbnails)
 		if (! GTK_WIDGET_REALIZED (priv->tree_view))
 			return;
 
+#if GTK_CHECK_VERSION (2, 11, 3)
+		gtk_tree_view_convert_widget_to_bin_window_coords (GTK_TREE_VIEW (priv->tree_view),
+								   0, (int) priv->vadjustment->value,
+								   NULL, &wy1);
+		gtk_tree_view_convert_widget_to_bin_window_coords (GTK_TREE_VIEW (priv->tree_view),
+								   0, (int) (priv->vadjustment->value + priv->vadjustment->page_size),
+								   NULL, &wy2);
+#else
 		gtk_tree_view_tree_to_widget_coords (GTK_TREE_VIEW (priv->tree_view),
 						     0, (int) priv->vadjustment->value,
 						     NULL, &wy1);
 		gtk_tree_view_tree_to_widget_coords (GTK_TREE_VIEW (priv->tree_view),
 						     0, (int) (priv->vadjustment->value + priv->vadjustment->page_size),
 						     NULL, &wy2);
+#endif /* GTK_CHECK_VERSION (2, 11, 3) */
+		
 		gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (priv->tree_view),
 					       1, wy1 + 1, &path,
 					       NULL, NULL, NULL);
@@ -393,27 +401,19 @@ ev_sidebar_thumbnails_fill_model (EvSidebarThumbnails *sidebar_thumbnails)
 static void
 ev_sidebar_thumbnails_set_loading_icon (EvSidebarThumbnails *sidebar_thumbnails)
 {
-	gint width = THUMBNAIL_WIDTH;
-	gint height = THUMBNAIL_WIDTH;
-
 	if (sidebar_thumbnails->priv->loading_icon)
 		g_object_unref (sidebar_thumbnails->priv->loading_icon);
 
-	if (sidebar_thumbnails->priv->document) {
-		EvRenderContext *rc;
+	if (sidebar_thumbnails->priv->document &&
+	    sidebar_thumbnails->priv->n_pages > 0) {
+		gint width, height;
 
-		rc = ev_render_context_new (sidebar_thumbnails->priv->rotation, 0,
-					    get_scale_for_page (sidebar_thumbnails, 0));
-
-		/* We get the dimensions of the first doc so that we can make a blank
+		/* We get the dimensions of the first page so that we can make a blank
 		 * icon.  */
-		ev_document_doc_mutex_lock ();
-		ev_document_thumbnails_get_dimensions (EV_DOCUMENT_THUMBNAILS (sidebar_thumbnails->priv->document),
-						       rc, &width, &height);
-		ev_document_doc_mutex_unlock ();
-		
-		g_object_unref (rc);
-		
+		ev_page_cache_get_thumbnail_size (sidebar_thumbnails->priv->page_cache, 0,
+						  sidebar_thumbnails->priv->rotation,
+						  &width, &height);
+
 		sidebar_thumbnails->priv->loading_icon =
 			ev_document_misc_get_thumbnail_frame (width, height, NULL);
 	} else {
@@ -436,15 +436,16 @@ ev_sidebar_thumbnails_refresh (EvSidebarThumbnails *sidebar_thumbnails,
 	sidebar_thumbnails->priv->rotation = rotation;
 	ev_sidebar_thumbnails_set_loading_icon (sidebar_thumbnails);
 
-	if (sidebar_thumbnails->priv->document == NULL)
+	if (sidebar_thumbnails->priv->document == NULL ||
+	    sidebar_thumbnails->priv->n_pages <= 0)
 		return;
 
 	ev_sidebar_thumbnails_clear_model (sidebar_thumbnails);
 	ev_sidebar_thumbnails_fill_model (sidebar_thumbnails);
 
 	/* Trigger a redraw */
-	sidebar_thumbnails->priv->start_page = 0;
-	sidebar_thumbnails->priv->end_page = 0;
+	sidebar_thumbnails->priv->start_page = -1;
+	sidebar_thumbnails->priv->end_page = -1;
 	g_idle_add ((GSourceFunc)refresh, sidebar_thumbnails);
 }
 
@@ -562,8 +563,12 @@ ev_sidebar_thumbnails_init (EvSidebarThumbnails *ev_sidebar_thumbnails)
 					       EV_TYPE_JOB_THUMBNAIL);
 
 	priv->swindow = gtk_scrolled_window_new (NULL, NULL);
+	
+	/* We actually don't want GTK_POLICY_AUTOMATIC for horizontal scrollbar here
+	 * it's just a workaround for bug #449462
+	 */
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (priv->swindow),
-					GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (priv->swindow),
 					     GTK_SHADOW_IN);
 	priv->vadjustment = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (priv->swindow));
@@ -674,51 +679,53 @@ ev_sidebar_thumbnails_set_document (EvSidebarPage	*sidebar_page,
 
 	/* Connect to the signal and trigger a fake callback */
 	g_signal_connect (priv->page_cache, "page-changed", G_CALLBACK (page_changed_cb), sidebar_thumbnails);
-	sidebar_thumbnails->priv->start_page = 0;
-	sidebar_thumbnails->priv->end_page = 0;
+	sidebar_thumbnails->priv->start_page = -1;
+	sidebar_thumbnails->priv->end_page = -1;
+	page_changed_cb (priv->page_cache,
+			 ev_page_cache_get_current_page (priv->page_cache),
+			 sidebar_thumbnails);
 	adjustment_changed_cb (sidebar_thumbnails);
 }
 
 static gboolean
 ev_sidebar_thumbnails_clear_job (GtkTreeModel *model,                                             
-			         GtkTreePath *path, 					                                                 
-			         GtkTreeIter *iter, 											                                              
+			         GtkTreePath *path,
+			         GtkTreeIter *iter,
 				 gpointer data)
 {
-    EvJob *job;
-    
-    gtk_tree_model_get (model, iter, COLUMN_JOB, &job, -1);
-    
-    if (job != NULL) {
-        ev_job_queue_remove_job (job);
-	g_signal_handlers_disconnect_by_func (job, thumbnail_job_completed_callback, data);
-    	g_object_unref (job);
-    }
-
-    return FALSE;    
+	EvJob *job;
+	
+	gtk_tree_model_get (model, iter, COLUMN_JOB, &job, -1);
+	
+	if (job != NULL) {
+		ev_job_cancel (job);
+		g_signal_handlers_disconnect_by_func (job, thumbnail_job_completed_callback, data);
+		g_object_unref (job);
+	}
+	
+	return FALSE;    
 }
 
 static void 
 ev_sidebar_thumbnails_clear_model (EvSidebarThumbnails *sidebar_thumbnails)
 {
-    EvSidebarThumbnailsPrivate *priv = sidebar_thumbnails->priv;
-    
-    gtk_tree_model_foreach (GTK_TREE_MODEL (priv->list_store), ev_sidebar_thumbnails_clear_job, sidebar_thumbnails);
-    gtk_list_store_clear (priv->list_store);
+	EvSidebarThumbnailsPrivate *priv = sidebar_thumbnails->priv;
+	
+	gtk_tree_model_foreach (GTK_TREE_MODEL (priv->list_store), ev_sidebar_thumbnails_clear_job, sidebar_thumbnails);
+	gtk_list_store_clear (priv->list_store);
 }
 
 static gboolean
 ev_sidebar_thumbnails_support_document (EvSidebarPage   *sidebar_page,
 				        EvDocument *document)
 {
-	return (EV_IS_DOCUMENT_THUMBNAILS (document) &&
-		    (ev_document_get_n_pages (document) > 1));
+	return (EV_IS_DOCUMENT_THUMBNAILS (document));
 }
 
 static const gchar*
 ev_sidebar_thumbnails_get_label (EvSidebarPage *sidebar_page)
 {
-    return _("Thumbnails");
+	return _("Thumbnails");
 }
 
 static void
