@@ -20,9 +20,7 @@
 #ifndef __EV_VIEW_H__
 #define __EV_VIEW_H__
 
-#include <gtk/gtkwidget.h>
-#include <gtk/gtklayout.h>
-#include <gtk/gtkscrolledwindow.h>
+#include <gtk/gtk.h>
 
 #include "ev-document.h"
 #include "ev-link.h"
@@ -75,6 +73,8 @@ void 		ev_view_set_loading       (EvView 	  *view,
 				           gboolean        loading);
 /* Clipboard */
 void		ev_view_copy		  (EvView         *view);
+void            ev_view_copy_link_address (EvView         *view,
+					   EvLinkAction   *action);
 void		ev_view_select_all	  (EvView         *view);
 gboolean        ev_view_get_has_selection (EvView         *view);
 
