@@ -19,16 +19,13 @@
 
 #include "config.h"
 
-#include "ev-application.h"
-#include "ev-metadata-manager.h"
-#include "ev-debug.h"
-
-#include <glib/gi18n.h>
-#include <gdk/gdkx.h>
-#include <gtk/gtkmain.h>
 #include <stdlib.h>
 #include <string.h>
 
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+#include <gdk/gdkx.h>
+
 #if WITH_GNOME
 #include <libgnome/gnome-program.h>
 #include <libgnomeui/gnome-ui-init.h>
@@ -40,10 +37,12 @@
 #include <dbus/dbus-glib-bindings.h>
 #endif
 
-#include "ev-stock-icons.h"
-#include "ev-job-queue.h"
-#include "ev-file-helpers.h"
+#include "ev-application.h"
 #include "ev-backends-manager.h"
+#include "ev-debug.h"
+#include "ev-file-helpers.h"
+#include "ev-metadata-manager.h"
+#include "ev-stock-icons.h"
 
 static gchar   *ev_page_label;
 static gchar   *ev_find_string;
@@ -391,7 +390,6 @@ main (int argc, char *argv[])
 		ev_metadata_manager_init ();
 	}
 
-	ev_job_queue_init ();
 	g_set_application_name (_("Evince Document Viewer"));
 
 	ev_file_helpers_init ();
@@ -418,6 +416,8 @@ main (int argc, char *argv[])
 
 	ev_backends_manager_shutdown ();
 
+	ev_debug_shutdown ();
+
 #if WITH_GNOME
  	g_object_unref (program);
 #endif
